@@ -10,21 +10,21 @@ FTN::Database - FTN SQL Database related operations for Fidonet/FTN related proc
 
 =head1 VERSION
 
-Version 0.30
+Version 0.34
 
 =cut
 
-our $VERSION = '0.30';
+our $VERSION = '0.34';
 
 =head1 DESCRIPTION
 
-FTN::Database is Perl modules containing common database related operations
-for Fidonet/FTN related SQL Database processing plus associated scripts.  The
-SQL database engine is one for which a DBD module exists, defaulting to SQLite.
+FTN::Database are Perl modules containing common database related operations
+and definitions for Fidonet/FTN related SQL Database processing. The SQL database
+engine is one for which a DBD module exists, defaulting to SQLite.
 
 =head1 EXPORT
 
-The following functions are available in this module:  create_ftn_database, open_ftn_database,
+The following functions are available in this module: create_ftn_database, open_ftn_database,
 close_ftn_database, drop_ftn_database, drop_ftn_table, create_ftn_index, and drop_ftn_index.
 
 =head1 FUNCTIONS
@@ -63,7 +63,7 @@ hash contains the following items:
 
 =item   Type
 
-The database type.  This needs to be a database type for which 
+The database type.  This needs to be a database type for which
 a DBD module exists, the type being the name as used in the DBD
 module.  The default type to be used is SQLite.
 
@@ -141,6 +141,37 @@ sub drop_ftn_database {
 
 }
 
+=head2 create_ftn_table
+
+Syntax:  create_ftn_table($db_handle, $table_name, $define_fields, $db_type);
+
+Create a table in an SQL database to be used for Fidonet/FTN processing, where
+$db_handle is an existing open database handle, $table_name is the name of the
+table to be created, $define_fields is the sql to define the fields to be used
+for table except for an id field, and $db_type is the type of database.
+
+=cut
+
+sub create_ftn_table {
+
+    my($db_handle, $table_name, $define_fields, $db_type) = @_;
+
+    my $sql_statement = "CREATE TABLE $table_name( ";
+    # If DB type is PostgreSQL, use SERIAL; else use INTEGER & AUTOINCREMENT
+    if ($db_type eq 'Pg') {
+        $sql_statement .= "id   SERIAL PRIMARY KEY NOT NULL, ";
+    } else {
+        $sql_statement .= "id   INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, ";
+    }
+    $sql_statement .= $define_fields;
+    $sql_statement .= ") ";
+
+    $db_handle->do("$sql_statement ") or croak($DBI::errstr);
+
+    return(0);
+
+}
+
 =head2 drop_ftn_table
 
 Syntax:  drop_ftn_table($db_handle, $table_name);
@@ -262,14 +293,15 @@ Robert James Clay, C<< <jame at rocasa.us> >>
 =head1 BUGS
 
 Please report any bugs or feature requests via the web interface at
-L<https://github.com/ftnpl/FTN-Database/issues>. I will be notified,
-and then you'll automatically be notified of progress on your bug
-as I make changes.
+L<http://sourceforge.net/p/ftnpl/ftn-database/tickets/>. I will be
+notified, and then you'll automatically be notified of progress on
+your bug as I make changes.
 
 Note that you can also report any bugs or feature requests to
 C<bug-ftn-database at rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=FTN-Database>;
-however, the FTN-Database Issue tracker is preferred.
+however, the FTN-Database Issue tracker at the SourceForge
+project  is preferred.
 
 =head1 SUPPORT
 
@@ -282,9 +314,9 @@ You can also look for information at:
 
 =over 4
 
-=item * FTN-Database issue tracker
+=item * FTN::Database issue tracker
 
-L<https://github.com/ftnpl/FTN-Database/issues>
+L<http://sourceforge.net/p/ftnpl/ftn-database/tickets/>
 
 =item * RT: CPAN's request tracker
 
@@ -294,17 +326,11 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=FTN-Database>
 
 L<http://search.cpan.org/dist/FTN-Database>
 
-Note that the version number in scripts matches up to the oldest version
-of the modules that they will run with.  The version in FTN::Database is
-always the primary version, while the version of the submodules matches
-up to the version at which they were last changed.
-
 =back
 
 =head1 SEE ALSO
 
- L<DBI>, L<FTN::Database::Nodelist>, L<ftndb-admin>,
- and L<ftndb-nodelist>
+ L<DBI>, L<FTN::Database::Nodelist>, L<FTN::Database::ToDo>
 
 =head1 COPYRIGHT & LICENSE
 
